@@ -1,4 +1,7 @@
-"anova.gamlist" <-
+#' @method anova Gamlist
+#' @export
+#' @export anova.Gamlist
+"anova.Gamlist" <-
 function(object, ..., test = c("none", "Chisq", "F", "Cp")){
   test=match.arg(test)
   class(object)="glmlist"
